require 'pathname'
require Pathname.new(__FILE__).parent + 'wiimote.rb'
require 'sdl' 


# initialize SDL
SDL.init( SDL::INIT_VIDEO ) 
screen = SDL.setVideoMode( 640, 480, 16, SDL::SWSURFACE )

# enable Motion Sensor
wiimote = Wiimote.new
wiimote.enable_motion_sensor

top_variation    = 10
height_variation = 20

SPAN          = 5
speed         = 2
UPDOWN_HEIGHT = 4

top, height = 100, 200
tops    = Array.new( 640 / ( SPAN * speed ) + 3 ) { top    += rand( top_variation    ) - top_variation / 2    }
heights = Array.new( 640 / ( SPAN * speed ) + 3 ) { height += rand( height_variation ) - height_variation / 2 }

i = 0

player_y         = 200
player_direction = UPDOWN_HEIGHT


# clear screen
screen.fillRect( 0, 0, 640, 480, [ 0, 0, 0 ] )
# update a screen
screen.updateRect( 0, 0, 0, 0 )

loop do
	while event = SDL::Event2.poll
		case event
		when SDL::Event2::Quit
			exit
		end
	end
	
	# read data from a wiimote
	wiimote.update
	
	break if wiimote.a
	
	sleep 0.1
end


loop do
	# process SDL events
	while event = SDL::Event2.poll
		case event
		when SDL::Event2::Quit
			exit
		when SDL::Event2::KeyDown
			case event.sym
			when SDL::Key::ESCAPE then exit
			# when SDL::Key::SPACE  then player_direction = -UPDOWN_HEIGHT
			end
		when SDL::Event2::KeyUp
			#case event.sym
			# when SDL::Key::SPACE  then player_direction = UPDOWN_HEIGHT
			#end
		end
	end
	
	# read data from a wiimote
	wiimote.update
	
	
	#   up-pointing: near  95
	#    horizontal: near 125
	# down-pointing: near 145
	case wiimote.yaxis
	when 000..105 then player_direction = -UPDOWN_HEIGHT
	when 105..115 then player_direction = -UPDOWN_HEIGHT / 2
	when 116..120 then player_direction = -UPDOWN_HEIGHT / 4
	when 121..126 then player_direction =  0
	when 127..129 then player_direction =  UPDOWN_HEIGHT / 4
	when 130..140 then player_direction =  UPDOWN_HEIGHT / 2
	when 141..255 then player_direction =  UPDOWN_HEIGHT
	end
	
	player_y += player_direction
	# puts "YAXIS:#{wiimote.yaxis}, player_direction: #{player_direction}"
	
	
	
	# clear screen
	screen.fillRect( 0, 0, 640, 480, [ 0, 0, 0 ] )
	
	# draw player
	screen.drawAAFilledEllipse( 20, player_y, 5, 5, [ 0xff, 0xff, 0xff ] )
	
	
	# draw cave
	last_x      = -10
	last_y      = tops[0]
	last_height = heights[0]
	(1...tops.size).each do |x|
		x, y, height = -10 - i % ( SPAN * speed ) + x * SPAN * speed, tops[x], heights[x]
		
		screen.drawLine( last_x, last_y              , x, y         , [ 0xff, 0xff, 0xff ] )
		screen.drawLine( last_x, last_y + last_height, x, y + height, [ 0xff, 0xff, 0xff ] )
		
		last_x, last_y, last_height = x, y, height
	end
	
	i += speed
	
	if i % SPAN == 0
		tops.shift
		heights.shift
		
		tops    <<    tops.last + rand( top_variation    ) -    top_variation / 2
		heights << heights.last + rand( height_variation ) - height_variation / 2
		
		tops[-1] = 20    if tops.last < 20
		tops[-1] = 400   if tops.last > 400
		
		heights[-1] = 30 if heights.last < 30
		
		top_variation    += 5 if top_variation    < 50
		height_variation -= 5 if height_variation > 30
	end
	
	# update a screen
	screen.updateRect( 0, 0, 0, 0 )
	
	# wait input
	sleep 0.015
end