require 'pathname'
require Pathname.new(__FILE__).parent + 'wiimote.rb'
require 'sdl' 


# helper functions to calculate vertex coordinates
MAX_LEN = 200

def coordinate_x_of_axisx( v ) 320 + v * 0                      /   0xff       end
def coordinate_x_of_axisy( v ) 320 - v * MAX_LEN * Math.sqrt(3) / ( 0xff * 2 ) end
def coordinate_x_of_axisz( v ) 320 + v * MAX_LEN * Math.sqrt(3) / ( 0xff * 2 ) end

def coordinate_y_of_axisx( v ) 280 - v * MAX_LEN /   0xff       end
def coordinate_y_of_axisy( v ) 280 + v * MAX_LEN / ( 0xff * 2 ) end
def coordinate_y_of_axisz( v ) 280 + v * MAX_LEN / ( 0xff * 2 ) end


# initialize SDL
SDL.init( SDL::INIT_VIDEO ) 
screen = SDL.setVideoMode( 640, 480, 16, SDL::SWSURFACE )

SDL::TTF.init
font = SDL::TTF.open( Pathname.new(__FILE__).parent + 'mplus-1m-regular.ttf', 24, 0 )

# enable Motion Sensor
wiimote = Wiimote.new
wiimote.enable_motion_sensor

# main loop
loop do
	# process SDL events
	while event = SDL::Event2.poll
		case event
		when SDL::Event2::Quit
			exit
		when SDL::Event2::KeyDown
			exit if event.sym == SDL::Key::ESCAPE
		end
	end
	
	# read data from a wiimote
	wiimote.update
	
	
	# clear screen
	screen.fillRect( 0, 0, 640, 480, [ 0, 0, 0 ] )
	
	
	# draw axises
	screen.drawLine( coordinate_x_of_axisx( 0x00 ), coordinate_y_of_axisx( 0x00 ), coordinate_x_of_axisx( 0xff ), coordinate_y_of_axisx( 0xff ), [ 0x00, 0x00, 0xff ] )
	screen.drawLine( coordinate_x_of_axisy( 0x00 ), coordinate_y_of_axisy( 0x00 ), coordinate_x_of_axisy( 0xff ), coordinate_y_of_axisy( 0xff ), [ 0x00, 0x00, 0xff ] )
	screen.drawLine( coordinate_x_of_axisz( 0x00 ), coordinate_y_of_axisz( 0x00 ), coordinate_x_of_axisz( 0xff ), coordinate_y_of_axisz( 0xff ), [ 0x00, 0x00, 0xff ] )
	
	
	# calculate vertex positions
	coordinates = [
		[ coordinate_x_of_axisx( wiimote.xaxis ), coordinate_y_of_axisx( wiimote.xaxis ) ],
		[ coordinate_x_of_axisy( wiimote.yaxis ), coordinate_y_of_axisy( wiimote.yaxis ) ],
		[ coordinate_x_of_axisz( wiimote.zaxis ), coordinate_y_of_axisz( wiimote.zaxis ) ]
	]
	# draw a triangle
	screen.drawLine( coordinates[0][0], coordinates[0][1], coordinates[1][0], coordinates[1][1], [ 0xff, 0xff, 0xff ] )
	screen.drawLine( coordinates[1][0], coordinates[1][1], coordinates[2][0], coordinates[2][1], [ 0xff, 0xff, 0xff ] )
	screen.drawLine( coordinates[2][0], coordinates[2][1], coordinates[0][0], coordinates[0][1], [ 0xff, 0xff, 0xff ] )
	
	# display the axis' values
	font.drawBlendedUTF8( screen, "x:#{wiimote.xaxis}", coordinate_x_of_axisx( 0xff ) - 34, coordinate_y_of_axisx( 0xff ) - 30, 0xff, 0xff, 0xff )
	font.drawBlendedUTF8( screen, "y:#{wiimote.yaxis}", coordinate_x_of_axisy( 0xff ) - 43, coordinate_y_of_axisy( 0xff ) +  8, 0xff, 0xff, 0xff )
	font.drawBlendedUTF8( screen, "z:#{wiimote.zaxis}", coordinate_x_of_axisz( 0xff ) - 21, coordinate_y_of_axisz( 0xff ) +  8, 0xff, 0xff, 0xff )
	
	
	# update a screen
	screen.updateRect( 0, 0, 0, 0 )
	
	# wait input
	sleep 0.015
end